@@ -1,5 +1,5 @@
 ﻿/***************************************************************************
- *   Copyright (C) 2021 by Abderrahman Taha                                *
+ *   Copyright (C) 2024 by Abderrahman Taha                                *
  *                                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -33,29 +33,25 @@
 
 int main(int argc, char *argv[])
 {
-    // QCoreApplication::setAttribute(Qt::AA_UseDesktopOpenGL);
     QApplication app(argc, argv);
-
-    QSurfaceFormat fmt;
-    fmt.setDepthBufferSize(24);
-    QSurfaceFormat::setDefaultFormat(fmt);
+    QSurfaceFormat format;
+    format.setDepthBufferSize(24);
+    QSurfaceFormat::setDefaultFormat(format);
     Parametersoptions Parameters;
-    Parameters.fileconfig2= app.applicationDirPath();
-    Parameters.MainApp = &app;
-    Parameters.LoadConfig(app, argc, argv);
-    // Creation of the two most important objects:
-    MathMod mm(nullptr, uint(Parameters.Threads[0]),
-               uint(Parameters.InitParGrid), uint(Parameters.InitIsoGrid),
-               uint(Parameters.CalculFactor[0]), uint(Parameters.CalculFactor[1]),
-               uint(Parameters.CalculFactor[2]));
+    Parameters.LoadConfig(argc, argv);
+    app.setStyle(QStyleFactory::create("Fusion"));
+    app.setPalette(Parameters.darkpalette);
+    QList<Qt::GestureType> gestures;
+    gestures << Qt::PinchGesture;
     DrawingOptions drawingopt;
+    drawingopt.grabGestures(gestures);
     // save references:
     drawingopt.Parameters = &Parameters;
-    drawingopt.MathmodRef = &mm;
-    mm.Parent = &drawingopt;
-    mm.Xgrid = mm.Ygrid = mm.Zgrid=uint(Parameters.InitIsoGrid);
-    mm.Ugrid = mm.Vgrid = uint(Parameters.InitParGrid);
+    drawingopt.MathmodRef = drawingopt.ui.openGLWidget;
+    drawingopt.ui.openGLWidget->Xgrid = drawingopt.ui.openGLWidget->Ygrid = drawingopt.ui.openGLWidget->Zgrid=uint(InitIsoGrid);
+    drawingopt.ui.openGLWidget->Ugrid = drawingopt.ui.openGLWidget->Vgrid = uint(InitParGrid);
     // GUI update:
+    drawingopt.show();
     drawingopt.UpdateGui(argc);
     if (drawingopt.IsolistItemRef != nullptr)
         drawingopt.ui.ObjectClasse->expandItem(drawingopt.IsolistItemRef);
@@ -83,12 +79,7 @@ int main(int argc, char *argv[])
     QObject::connect(drawingopt.MathmodRef->IsoObjet,
                      SIGNAL(finished()), drawingopt.MathmodRef,
                      SLOT(UpdateGL()), Qt::UniqueConnection);
-    QObject::connect(drawingopt.Parameters->ui.ApplypushButton, SIGNAL(clicked()),
-                     &drawingopt, SLOT(ApplypushButton_clicked()));
-    drawingopt.show();
-    mm.show();
-    drawingopt.raise();
-    mm.LoadShadersFiles();
+    drawingopt.ui.openGLWidget->LoadShadersFiles();
     drawingopt.on_choice_activated(Parameters.model);
     return app.exec();
 }
