@@ -1,12 +1,19 @@
 {
-    "Version": {
-        "Number": 11.1
+    "ReleaseInfos": {
+        "VersionNumber": "1200",
+        "ReleaseDate": "211220",
+        "DocPartialPath": "/documentation/index.html",
+        "DocAbsolutePath": "https://github.com/parisolab/mathmod/wiki/documentation"
     },
     "Parameters": {
         "IsoMaxGrid": 500,
-        "InitIsoGrid": 64,
+        "InitIsoGrid": 41,
         "ParMaxGrid": 5000,
-        "InitParGrid": 64
+        "InitParGrid": 64,
+        "ScriptEditorFontSize": 18
+    },
+    "StartOptions": {
+        "Model": "CloseIso_1"
     },
     "StartOptions": {
         "Model": "CloseIso_1"
@@ -19,7 +26,7 @@
     },
     "WindowSize": {
         "ControlH": 750,
-        "ControlW": 450,
+        "ControlW": 1200,
         "GlwinH": 750,
         "GlwinW": 750
     },
@@ -44,27 +51,5 @@
         "GL_DIFFUSE" : [80, 80, 80, 100],
         "GL_SHININESS": 20,
         "GL_FrontFacingSupport": true
-    },
-    "Styles": {
-        "PredefinedStyle": [ "Default", "Fusion", "Windows","WindowsXp"],
-        "UsedStyle": "Fusion"
-    },
-    "Themes": {
-        "PredefinedThemes": [ "Default", "Dark", "MyTheme"],
-        "UsedTheme": "Dark",
-        "MyTheme": {
-            "Window":[53,53,53],
-            "WindowText":[255, 255, 255],
-            "Base":[15,15,15],
-            "AlternateBase":[53,53,53],
-            "ToolTipBase":[255, 255, 255],
-            "ToolTipText":[255, 255, 255],
-            "Text":[2, 2, 255],
-            "Button":[53,53,53],
-            "ButtonText":[255, 255, 255],
-            "BrightText":[255, 0, 0],
-            "Highlight":[142,45,197],
-            "HighlightedText":[0, 0, 0]
-        }
     }
 }
