@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2021 by Abderrahman Taha                                *
+ *   Copyright (C) 2024 by Abderrahman Taha                                *
  *                                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -43,7 +43,102 @@ static int permutation[256] =
     180
 };
 
+double julia(double zx, double zy, double cx, double cy, int MAXCOUNT)
+{
+    double tempx;
+    int count;
+    count = 0;
+    while ((zx * zx + zy * zy < 4) && (count < MAXCOUNT))
+    {
+        tempx = zx * zx - zy * zy + cx;
+        zy = 2 * zx * zy + cy;
+        zx = tempx;
+        count = count + 1;
+    }
+    return (double(count));
+}
 
+double mandelbrot(double cx, double cy, int MAXCOUNT)
+{
+    double zx, zy, tempx, Zx, Zy;
+    int count;
+    zx = 0;
+    zy = 0;
+    count = 0;
+    while (((Zx=(zx * zx)) + (Zy=(zy * zy)) < 4) && (count < MAXCOUNT))
+    {
+        tempx = Zx -  Zy + cx;
+        zy = 2 * zx * zy + cy;
+        zx = tempx;
+        count = count + 1;
+    }
+    return (double(count));
+}
+
+//associated legendre
+double legendre_a (int n, int m, double x)
+{
+    std::vector<double> v(n+1, 0.0);
+    if(m <= n ) {
+    v[m] = 1.0;
+        double fact = 1.0;
+        for(int k = 0; k < m; k++) {
+            v[m] *= -fact * std::sqrt(1.0 - x * x);
+            fact += 2.0;
+        }
+    }
+    if(m + 1 <= n ) {
+        v[m+1] = x * ( double ) ( 2 * m + 1 ) * v[m];
+    }
+    for(int j = m + 2; j <= n; j++ ) {
+        v[j] = ((double)(2 * j - 1 ) * x * v[(j-1)]
+                + (double)(- j - m + 1 ) * v[(j-2)])
+                / (double)(j - m);
+    }
+    return v[n];
+}
+
+//associated laguerre
+double laguerre_a(int n, int m, double x) {
+    double v[n+1];
+    if (n < 0) {
+        return -1;
+    }
+    v[0] = 1.0;
+    for (int i = 1; i <= n; i++) {
+        v[i] = 0.0;
+    }
+    if (n == 0) {
+        return v[0];
+    }
+    v[1] = (double)(m + 1) - x;
+    for (int i = 2; i <= n; i++) {
+        v[i] = (((double)(m + 2 * i - 1) - x) * v[i-1]
+               + ( double ) (-m - i + 1 ) * v[i-2])
+               / ( double ) (i);
+    }
+    return v[n];
+}
+
+double Julia(const double* pp)
+{
+    return(julia (pp[0], pp[1], pp[2], pp[3], int (pp[4])));
+}
+
+double Mandelbrot(const double* pp)
+{
+    return(mandelbrot (pp[0], pp[1], int (pp[2])));
+}
+
+double Legendre_a(const double* pp)
+{
+    return(legendre_a (int (pp[0]), int (pp[1]), pp[2]));
+}
+
+double Laguerre_a(const double* pp)
+{
+    return(laguerre_a (int (pp[0]), int (pp[1]), pp[2]));
+}
 
 float tinyrnd()
 {
@@ -63,7 +158,6 @@ float CellNoise::CellNoiseFunc(float x, float y, float z, int seed, int type, in
     int evalCubeX = int(floor(x));
     int evalCubeY = int(floor(y));
     int evalCubeZ = int(floor(z));
-
     for (int i = -1; i < 2; ++i)
         for (int j = -1; j < 2; ++j)
             for (int k = -1; k < 2; ++k)
@@ -197,9 +291,7 @@ ImprovedNoise::ImprovedNoise(float xsize, float ysize, float zsize)
     for (int i = 0; i < 256; i++)
     {
         int k = int((tinyrnd() * (256 - i) + i));
-
         int l = p[i];
-
         p[i] = p[k];
         p[k] = l;
         p[i + 256] = p[i];
@@ -215,7 +307,6 @@ float ImprovedNoise::noise(float x, float y, float z)
     float u = fade(x), v = fade(y), w = fade(z);
     int A = p[X] + Y, AA = p[A] + Z, AB = p[A + 1] + Z, B = p[X + 1] + Y,
         BA = p[B] + Z, BB = p[B + 1] + Z;
-
     return lerp(
                w,
                lerp(v, lerp(u, grad(p[AA], x, y, z), grad(p[BA], x - 1, y, z)),
