@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2021 by Abderrahman Taha                                *
+ *   Copyright (C) 2024 by Abderrahman Taha                                *
  *                                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -17,6 +17,9 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor,Boston, MA 02110-1301 USA             *
  ***************************************************************************/
+#ifndef COMMUN_H
+#define COMMUN_H
+
 #include "../fparser/fparser.hh"
 #include <qthread.h>
 #include <complex.h>
@@ -26,6 +29,11 @@
 #define MAGIC_SCALE 1.5707963f
 extern template class FunctionParserBase<double>; // explicit instantiation
 
+double Mandelbrot(const double*);
+double Julia(const double*);
+double Legendre_a(const double*);
+double Laguerre_a(const double*);
+
 struct GlobalParam
 {
     uint TypeDrawin = 10;
@@ -209,7 +217,6 @@ struct ObjectProperties
     int norm = -1;
     int plan = 1;
     int axe = 1;
-    int attachwininfos = 1;
     int png_ok =  1;
     int jpg_ok = -1;
     int bmp_ok = -1;
@@ -281,3 +288,4 @@ extern std::vector<uint> IndexPolyTabMinVector;
 extern std::vector<uint> IndexPolyTabMinVector2;
 extern std::vector<uint> IndexPolyTabVector;
 static struct ComponentInfos *components = new (struct ComponentInfos);
+#endif // COMMUN_H
