@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2021 by Abderrahman Taha                                *
+ *   Copyright (C) 2024 by Abderrahman Taha                                *
  *                                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -21,7 +21,6 @@
 #ifndef ISOTRANSFORMATION
 #define ISOTRANSFORMATION
 
-#endif // ISOTRANSFORMATION
 #include <QtCore>
 #include "../commun.h"
 
@@ -31,11 +30,12 @@ class IsoTransformation
 public:
     int scalex, scaley, scalez;
     int twistx, twisty, twistz;
+    int translx, transly, translz;
 public:
-    //void IsoTransformation(FunctionParser);
     QString Twistx(QString);
     QString Twisty(QString);
     QString Twistz(QString);
     void Twist();
-
 };
+
+#endif // ISOTRANSFORMATION
