@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2021 by Abderrahman Taha                                *
+ *   Copyright (C) 2024 by Abderrahman Taha                                *
  *                                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -32,6 +32,8 @@ public:
 
 public:
     Ui::AddParamForm ui;
+private slots:
+    void on_pushButton_clicked();
 };
 
 #endif // ADDPARAM
