@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2021 by Abderrahman Taha                                *
+ *   Copyright (C) 2024 by Abderrahman Taha                                *
  *                                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -24,7 +24,6 @@
 #include "../screenshot/video.h"
 #include "about.h"
 #include "addparam.h"
-#include "colorsoptions.h"
 #include "editor.h"
 #include "mathmod.h"
 #include "parametersoptions.h"
@@ -91,6 +90,7 @@ public:
     QTreeWidgetItem *IsolistItemRef;
     Parametersoptions *Parameters;
     SelectOptions select;
+    int infos=-1;
     Ui::DrawingOptions ui;
     QJsonObject JSONMathModels;
     SliderStruct *SliderArray;
@@ -101,6 +101,8 @@ public:
     std::vector<MandatoryIsoField> MandIsoFields;
     std::vector<MandatoryParField> MandParFields;
     bool ShowCurrentObjectTree = false;
+    void on_choice_activated(const QString &);
+    void grabGestures(const QList<Qt::GestureType> &gestures);
 public slots:
     void removeat(int, QJsonObject&, QString);
     void removeat2(int, QJsonObject&, QString);
@@ -131,14 +133,13 @@ public slots:
     void SaveSlidersRef(int n = 20);
     void editorwin();
     void videoplay();
-    void colorsoptions();
+    void SaveToFile_CurentMathModel(QJsonObject);
+    void ReadCollectionFile(QString, QJsonObject &);
     void on_xyzg_valueChanged(int);
     void on_ChangeGrid_clicked();
-    int on_choice_activated(const QString &);
     void LoadK3DSurfScript(QString, int);
     void slot_comboBox18_3_activated(const QString &);
     void slot_checkBox_clicked();
-    void on_pushButton_clicked();
     void on_action_Exit_triggered();
     void on_actionTriangles_triggered();
     void on_actionInfos_triggered();
@@ -221,7 +222,6 @@ public slots:
     void ShowSliders(const QJsonObject &);
     void on_actionScreenshot_triggered();
     void on_actionEditor_triggered();
-    void on_actionColors_triggered();
     void update_slider_param();
     void add_new_param();
     void update_infos_param(int);
@@ -229,17 +229,8 @@ public slots:
     void ParseItemTree(QTreeWidgetItem *, QList<bool> &, bool view = false);
     QTreeWidgetItem *ChildItemTreeProperty(QTreeWidgetItem *item,
                                            QString proprty);
-private slots:
-    void on_Infos_clicked();
-    void on_Mesh_clicked();
-    void on_Fill_clicked();
-    void on_Trian_clicked();
-    void on_actionOpenGL_triggered();
     void on_cut_clicked();
     void on_actionConvert_K3DS_script_triggered();
-    void on_actionConfiguration_triggered();
-    void on_actionColors_2_triggered();
-    void on_Load_clicked();
     void on_ParamComponent_2_activated(int);
     void on_updateParam_2_clicked();
     void on_Multiplier_clicked();
@@ -330,13 +321,12 @@ private slots:
     void on_lineScrollBar_valueChanged(int);
     void on_coloneScrollBar_valueChanged(int);
     void on_actionScripts_selection_triggered();
-    void on_actionBoundingBox_clicked();
+    //void on_actionBoundingBox_clicked();
     void on_actionAnimation_Rotation_triggered();
     void on_actionMorph_use_t_parameter_triggered();
     void on_TreeViewButton_clicked();
-    void ApplypushButton_clicked();
-    void on_ObjectClasseCurrent_clicked(const QModelIndex &index);
-    void on_parisocomboBox_currentIndexChanged(int index);
+    void on_ObjectClasseCurrent_clicked(const QModelIndex &);
+    void on_parisocomboBox_currentIndexChanged(int);
     void on_ApplypushButton_clicked();
     void on_ApplypushButton_2_clicked();
     void on_ApplypushButton_3_clicked();
@@ -349,15 +339,17 @@ private slots:
     void on_ShowParComp_clicked();
     void on_actionAxe_triggered();
     void on_actionPlan_triggered();
-    void on_actionDetach_WinInfos_triggered();
-    void on_red_Ambient_valueChanged(int value);
-    void on_green_Ambient_valueChanged(int value);
-    void on_blue_Ambient_valueChanged(int value);
-    void on_transparent_Ambient_valueChanged(int value);
-    void on_red_Diffuse_valueChanged(int value);
-    void on_green_Diffuse_valueChanged(int value);
-    void on_blue_Diffuse_valueChanged(int value);
-    void on_transparent_Diffuse_valueChanged(int value);
+    void on_red_Ambient_valueChanged(int);
+    void on_green_Ambient_valueChanged(int);
+    void on_blue_Ambient_valueChanged(int);
+    void on_transparent_Ambient_valueChanged(int);
+    void on_red_Diffuse_valueChanged(int);
+    void on_green_Diffuse_valueChanged(int);
+    void on_blue_Diffuse_valueChanged(int);
+    void on_transparent_Diffuse_valueChanged(int);
     void on_GLFrontSurfaceSupport_clicked();
+private slots:
+    void on_actionbox_triggered();
 };
+
 #endif
