@@ -1,5 +1,5 @@
 ﻿/***************************************************************************
- *   Copyright (C) 2021 by Abderrahman Taha                                *
+ *   Copyright (C) 2024 by Abderrahman Taha                                *
  *                                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -19,6 +19,7 @@
  ***************************************************************************/
 #include "mathmod.h"
 
+
 void MathMod::CalculateTexturePoints(int type)
 {
     double tmp, val[6]={0,0,0,0,0,0};
@@ -35,7 +36,7 @@ void MathMod::CalculateTexturePoints(int type)
         ? LocalScene.componentsinfos.NoiseParam[0].NoiseShape = 0
                 : LocalScene.componentsinfos.NoiseParam[0].NoiseShape = 1;
     }
-    if (type == 0)
+    else if (type == 0)
     {
         LocalScene.componentsinfos.ThereisRGBA[0] = true;
         LocalScene.componentsinfos.NoiseParam[0].NoiseType = 1;
@@ -116,7 +117,7 @@ void MathMod::CalculatePigmentPoints(int type)
         ? LocalScene.componentsinfos.NoiseParam[0].NoiseShape = 0
                 : LocalScene.componentsinfos.NoiseParam[0].NoiseShape = 1;
     }
-    if (type == 0)
+    else if (type == 0)
     {
         LocalScene.componentsinfos.ThereisRGBA[0] = true;
         LocalScene.componentsinfos.NoiseParam[0].NoiseType = 0; // Pigments
@@ -165,6 +166,7 @@ void MathMod::CalculatePigmentPoints(int type)
         for (uint j = 0;
                 j < LocalScene.componentsinfos.NoiseParam[0].Nb_vrgbts && j < 100;
                 j += 5)
+            //ValCol array has undefined values
             if (tmp <= ValCol[j])
             {
                 LocalScene.ArrayNorVer_localPt[i*10  ] = float(ValCol[j+1]);
@@ -186,7 +188,7 @@ int MathMod::memoryallocation(uint nbthreads,
         ParObjet = new Par3D(nbthreads, initparGrid);
         return 1;
     }
-    catch (std::bad_alloc &)
+    catch (const std::bad_alloc&)
     {
         message.setText("Not enough memory available to complete this operation");
         message.adjustSize();
@@ -261,7 +263,7 @@ void MathMod::SaveSceneAsObjPoly(int type)
         }
         else if(LocalScene.typedrawing == -1)
         {
-            //**** Parametrics components ***/
+            //**** Parametric components ***/
             uint ugrid=0;
             uint vgrid =0;
             uint index=0;
@@ -283,7 +285,7 @@ void MathMod::SaveSceneAsObjPoly(int type)
         }
         else
         {
-            //**** Parametrics components ***/
+            //**** Parametric components ***/
 
             uint ugrid=0;
             uint vgrid =0;
@@ -304,7 +306,7 @@ void MathMod::SaveSceneAsObjPoly(int type)
                  index += ugrid*vgrid;
             }
 
-           // Isosurfaces components
+           // Isosurface components
            startpl = LocalScene.PolyNumber+LocalScene.componentsinfos.MinParametricMeshLines;
            uint kl=  LocalScene.componentsinfos.NbParametricMeshLines;
            for (uint i = kl; i < LocalScene.NbPolygnNbVertexPtMin; i++)
@@ -318,7 +320,6 @@ void MathMod::SaveSceneAsObjPoly(int type)
                }
                (stream) << "\n";
            }
-
         }
     }
 }
@@ -627,40 +628,48 @@ void MathMod::PutObjectInsideCube()
     }
     else
         polynb = LocalScene.NbPolygnNbVertexPtMin;
-
-    labelinfos = "  \n Grid     : ";
+  labelinfos = "";
+  if((LocalScene.typedrawing == 1) || (LocalScene.typedrawing == -1))
+  {
+    labelinfos = "Grid[";
     (LocalScene.typedrawing == 1)
     ? labelinfos += QString::number(Xgrid - CutX) + "x" +
             QString::number(Ygrid - CutY) + "x" +
-            QString::number(Zgrid - CutZ) +" \n"
+            QString::number(Zgrid - CutZ)+"]"
             : labelinfos += QString::number(Ugrid - CutU) + "x" +
-                    QString::number(Vgrid - CutV) +" \n";
-    labelinfos+=" Vertices : "+QString::number(LocalScene.VertxNumber)+" \n"+
-                           " Triangles: "+QString::number(LocalScene.PolyNumber/3)+" \n"
-                           " Polygons : "+QString::number(polynb)+" \n";
-   if(LocalScene.morph==-1)
-       labelinfos+=" X["+QString::number(minx,'g',3)+","+QString::number(maxx,'g',3)+"]\n\
- Y["+QString::number(miny,'g',3)+","+QString::number(maxy,'g',3)+"]\n\
- Z["+QString::number(minz,'g',3)+","+QString::number(maxz,'g',3)+"]\n";
+                    QString::number(Vgrid - CutV)+"]";
+  }
+  labelinfos+=" Vertices["+QString::number(LocalScene.VertxNumber)+"]"+
+                           " Triangls["+QString::number(LocalScene.PolyNumber/3)+"]"+
+                           " Polygons["+QString::number(polynb)+"]";
+  if(LocalScene.morph==-1)
+       labelinfos+=" X["+QString::number(minx,'g',3)+","+QString::number(maxx,'g',3)+"]\
+ Y["+QString::number(miny,'g',3)+","+QString::number(maxy,'g',3)+"]\
+ Z["+QString::number(minz,'g',3)+","+QString::number(maxz,'g',3)+"]";
 else
-       labelinfos+=" X["+QString::number(oldminx,'g',3)+","+QString::number(oldmaxx,'g',3)+"]\n\
- Y["+QString::number(oldminy,'g',3)+","+QString::number(oldmaxy,'g',3)+"]\n\
- Z["+QString::number(oldminz,'g',3)+","+QString::number(oldmaxz,'g',3)+"]\n";
+       labelinfos+=" X["+QString::number(oldminx,'g',3)+","+QString::number(oldmaxx,'g',3)+"]\
+ Y["+QString::number(oldminy,'g',3)+","+QString::number(oldmaxy,'g',3)+"]\
+ Z["+QString::number(oldminz,'g',3)+","+QString::number(oldmaxz,'g',3)+"]";
 
-    if(LocalScene.morph==1)
-    {
-        if(LocalScene.anim==-1)
-            LabelInfos.setText(labelinfos+" Morph: ON \n");
-        else
-            LabelInfos.setText(labelinfos+" Rotation/Morph: ON \n");
-    }
-    else
-    {
-        if(LocalScene.anim==-1)
-            LabelInfos.setText(labelinfos);
-        else
-            LabelInfos.setText(labelinfos+" Rotation: ON \n");
-    }
+   if(LocalScene.typedrawing == 1)
+   {
+       IsoObjet->message = labelinfos + IsoObjet->message;
+       IsoObjet->emitUpdateMessageSignal();
+       IsoObjet->message = "";
+   }
+   else if(LocalScene.typedrawing == -1)
+        {
+           ParObjet->message = labelinfos + ParObjet->message;
+           ParObjet->emitUpdateMessageSignal();
+           ParObjet->message = "";
+        }
+       else
+       {
+           IsoObjet->message = labelinfos + " ISO:" + IsoObjet->message + " PAR:" + ParObjet->message;
+           IsoObjet->emitUpdateMessageSignal();
+           IsoObjet->message = "";
+           ParObjet->message = "";
+       }
 }
 
 void MathMod::png()
@@ -813,7 +822,8 @@ void MathMod::DrawPariso(ObjectProperties *scene, uint ParisoTypeIndex)
     }
     else
     {
-        glUniform1i(uniformHSVactive, scene->componentsinfos.hsv[ParisoTypeIndex]?1:0);
+        if(scene->componentsinfos.hsv.size()>0)
+            glUniform1i(uniformHSVactive, scene->componentsinfos.hsv[ParisoTypeIndex]?1:0);
         glUniform1i(uniformThereisRGBA, 0);
     }
 
@@ -878,7 +888,6 @@ void MathMod::DrawPariso(ObjectProperties *scene, uint ParisoTypeIndex)
         }
     }
     glDisable(GL_POLYGON_OFFSET_FILL);
-    //glUniform1i(uniformThereisRGBA, 0);
 }
 
 void MathMod::normOk()
@@ -948,11 +957,11 @@ void MathMod::CreateShaderProgram()
         std::cout << "Could not create Vertex Shader!";
     }
     static const char *c_str_vertex =
+
             R"(
-            // GLSL version
-            //#version 120
             #ifdef GL_ES
             precision mediump float;
+            precision mediump int;
             #endif
             // uniforms
             uniform mat4 matrixModelView;
@@ -979,6 +988,40 @@ void MathMod::CreateShaderProgram()
                 gl_Position =  matrixModelViewProjection * vec4(vertexPosition, 1.0);
             }
             )";
+
+/*
+            R"(#version 300 es
+            #ifdef GL_ES
+            // Set default precision to medium
+            precision mediump int;
+            precision mediump float;
+            #endif
+            // uniforms
+            uniform mat4 matrixModelView;
+            uniform mat4 matrixNormal;
+            uniform mat4 matrixModelViewProjection;
+            uniform int glFrontFacing_1;
+            // vertex attribs (input)
+            in vec3 vertexPosition;
+            in vec3 vertexNormal;
+            in vec4 vertexColor;
+            // varyings (output)
+            out vec3 esVertex, esNormal;
+            out vec4 color;
+            out vec4 v_position;
+            void main()
+            {
+                esVertex = vec3(matrixModelView * vec4(vertexPosition, 1.0));
+                esNormal = vec3(matrixNormal * vec4(vertexNormal, 1.0));
+                color = vertexColor;
+                if(glFrontFacing_1 == 0)
+                {
+                    v_position = -matrixModelView * vec4 (vertexPosition, 1.0);
+                }
+                gl_Position =  matrixModelViewProjection * vec4(vertexPosition, 1.0);
+            }
+            )";
+*/
     glShaderSource(vertexshader, 1, &c_str_vertex, NULL);
     glCompileShader(vertexshader);
     glGetShaderiv(vertexshader, GL_COMPILE_STATUS, &IsCompiled_VS);
@@ -1004,11 +1047,11 @@ void MathMod::CreateShaderProgram()
         std::cout << "Could not create Fragment Shader!";
     }
     static const char *c_str_fragment =
+
             R"(
-            // GLSL version
-            //#version 120
             #ifdef GL_ES
             precision mediump float;
+            precision mediump int;
             #endif
             // uniforms
             uniform vec4 frontColor;
@@ -1104,6 +1147,115 @@ void MathMod::CreateShaderProgram()
                 gl_FragColor = fragColor;
             }
             )";
+
+
+/*
+            R"(#version 300 es
+            #ifdef GL_ES
+            // Set default precision to medium
+            precision mediump int;
+            precision mediump float;
+            #endif
+            // uniforms
+            uniform vec4 frontColor;
+            uniform vec4 backColor;
+            uniform vec4 gridColor;
+            uniform vec4 lightPosition;
+            uniform vec4 lightAmbient;
+            uniform vec4 lightDiffuse;
+            uniform vec4 lightSpecular;
+            uniform int hsvactive;
+            uniform int thereisRGBA;
+            uniform int drawgridColor;
+            uniform float shininess;
+            uniform int glFrontFacing_2;
+            // varyings
+            //layout(location=0) out vec3 esVertex;
+            //layout(location=1) out vec3 esNormal;
+            //layout(location=2) out vec4 color;
+            //layout(location=3) out vec4 v_position;
+
+            in vec3 esVertex, esNormal;
+            in vec4 color, v_position;
+            layout(location = 0) out vec4 fragColor;
+
+            // All components are in the range [0…1], including hue.
+            vec3 hsv2rgb(vec3 c)
+            {
+                vec4 K = vec4(1.0, 2.0 / 3.0, 1.0 / 3.0, 3.0);
+                vec3 p = abs(fract(c.xxx + K.xyz) * 6.0 - K.www);
+                return c.z * mix(K.xxx, clamp(p - K.xxx, 0.0, 1.0), c.y);
+            }
+
+            void main()
+            {
+                vec4 color1=color;
+                vec3 normal = normalize(esNormal);
+                if(glFrontFacing_2 == 1)
+                {
+                    if(gl_FrontFacing == false)
+                    {
+                        normal *= -1.0;
+                        if(thereisRGBA ==1)
+                        {
+                            color1=backColor;
+                        }
+
+                    }
+                    else
+                    {
+                        if(thereisRGBA ==1)
+                        {
+                            color1=frontColor;
+                        }
+                    }
+                }
+                else
+                {
+                    if(dot(normal, v_position.xyz) <= 0.0)
+                    {
+                        normal *= -1.0;
+                        if(thereisRGBA ==1)
+                        {
+                            color1=backColor;
+                        }
+                    }
+                    else
+                    {
+                        if(thereisRGBA ==1)
+                        {
+                            color1=frontColor;
+                        }
+                    }
+                }
+                if(drawgridColor == 1)
+                {
+                    color1=gridColor;
+                }
+                vec3 light;
+                if(lightPosition.w == 0.0)
+                {
+                    light = normalize(lightPosition.xyz);
+                }
+                else
+                {
+                    light = normalize(lightPosition.xyz - esVertex);
+                }
+                if(hsvactive == 1)
+                    color1 = vec4(hsv2rgb(color1.xyz), color1.w);
+                vec3 view = normalize(-esVertex);
+                vec3 halfv = normalize(light + view);
+                fragColor = lightAmbient * color1;
+                float dotNL = max(dot(normal, light), 0.0);
+                fragColor += lightDiffuse* color1 * dotNL;          // add diffuse
+                float dotNH = max(dot(normal, halfv), 0.0);
+                fragColor += (pow(dotNH, shininess) * lightSpecular) * color1; // add specular
+                // set frag color
+                //gl_FragColor = (hsvactive == 1)? vec4(hsv2rgb(fragColor.xyz), fragColor.w) : fragColor;
+                //gl_FragColor = fragColor;
+            }
+            )";
+            */
     glShaderSource(fragmentshader, 1, &c_str_fragment, NULL);
     glCompileShader(fragmentshader);
     glGetShaderiv(fragmentshader, GL_COMPILE_STATUS, &IsCompiled_FS);
@@ -1216,17 +1368,12 @@ void MathMod::anim()
     if (LocalScene.anim == 1)
     {
         timer->start(latence, this);
-        if (LocalScene.morph == -1)
-        {
-            LabelInfos.setText(labelinfos+" Rotation: ON \n");
-        }
     }
     else
     {
         oldRotation = rotation;
         if (LocalScene.morph == -1)
         {
-            LabelInfos.setText(labelinfos);
             stoptimer();
         }
     }
@@ -1277,13 +1424,8 @@ void MathMod::morph()
     {
         if (LocalScene.anim == -1)
         {
-            LabelInfos.setText(labelinfos);
             stoptimer();
         }
-        else
-        {
-            LabelInfos.setText(labelinfos+" Rotation: ON \n");
-        }
     }
 }
 
@@ -1292,15 +1434,12 @@ void MathMod::keyPressEvent(QKeyEvent *e)
     int key = e->key();
     switch (key)
     {
-    case Qt::CTRL+Qt::Key_A:
+    case Qt::CTRL|Qt::Key_A:
         anim();
         break;
-    case Qt::CTRL+Qt::Key_P:
+    case Qt::CTRL|Qt::Key_P:
         morph();
         break;
-     case Qt::Key_C:
-        Parent->show();
-        break;
     }
     update();
 }
@@ -1716,7 +1855,7 @@ void MathMod::mouseReleaseEvent(QMouseEvent *)
 void MathMod::mousePressEvent(QMouseEvent *e)
 {
     // Save mouse press position
-    mousePressPosition = QVector2D(e->localPos());
+    mousePressPosition = QVector2D(e->pos());
     if(LocalScene.anim != 1)
         rotation = oldRotation;
     if (e->button() == Qt::LeftButton)
@@ -1739,12 +1878,12 @@ void MathMod::mousePressEvent(QMouseEvent *e)
         btdroit = 0;
         mouseRightDown =false;
     }
-    if (e->button() == Qt::MidButton)
+    if (e->button() == Qt::MiddleButton)
         btmilieu = 1;
     else
         btmilieu = 0;
 
-    mouseY = e->y()/2;
+    mouseY = e->pos().y()/2;
 }
 
 void MathMod::mouseMoveEvent(QMouseEvent *e)
@@ -1753,7 +1892,7 @@ void MathMod::mouseMoveEvent(QMouseEvent *e)
     static QVector3D oldn=QVector3D(0,0,1);
     if(mouseLeftDown)
     {
-        QVector2D diff = QVector2D(e->localPos()) - mousePressPosition;
+        QVector2D diff = QVector2D(e->pos()) - mousePressPosition;
         // Rotation axis is perpendicular to the mouse position difference
         n = QVector3D(diff.y(), diff.x(), 0.0).normalized();
         // Accelerate angular speed relative to the length of the mouse sweep
@@ -1764,12 +1903,45 @@ void MathMod::mouseMoveEvent(QMouseEvent *e)
     }
     if(mouseRightDown)
     {
-        cameraDistance -= (e->y()/2 - mouseY) * 0.02f;
-        mouseY = e->y()/2;
+        cameraDistance -= (e->pos().y()/2 - mouseY) * 0.02f;
+        mouseY = e->pos().y()/2;
     }
     update();
 }
 
+bool MathMod::gestureEvent(QGestureEvent *event)
+{
+    if (QGesture *pinch = event->gesture(Qt::PinchGesture))
+        pinchTriggered(static_cast<QPinchGesture *>(pinch));
+    return true;
+}
+qreal scaleFactor = 1;
+void MathMod::pinchTriggered(QPinchGesture *gesture)
+{
+    QPinchGesture::ChangeFlags changeFlags = gesture->changeFlags();
+    if (changeFlags & QPinchGesture::ScaleFactorChanged) {
+            scaleFactor = gesture->scaleFactor();
+            if(scaleFactor != 0.0f)
+                cameraDistance /= scaleFactor;
+    }
+    update();
+}
+void MathMod::grabGestures(const QList<Qt::GestureType> &gestures)
+{
+    //! [enable gestures]
+    for (Qt::GestureType gesture : gestures)
+        grabGesture(gesture);
+    //! [enable gestures]
+}
+
+//! [event handler]
+bool MathMod::event(QEvent *event)
+{
+    if (event->type() == QEvent::Gesture)
+        return gestureEvent(static_cast<QGestureEvent*>(event));
+    return QWidget::event(event);
+}
+//! [event handler]
 void MathMod::screenshot()
 {
     QImage image = QOpenGLWidget::grabFramebuffer();
@@ -1923,6 +2095,7 @@ MathMod::MathMod(QWidget *parent, uint nbthreads,
                  uint initparGrid, uint initisoGrid, uint FactX, uint FactY,
                  uint FactZ) :QOpenGLWidget(parent)
 {
+    //nbthreads = Threads[0];
     PerlinNoise = new ImprovedNoise(4., 4., 4.);
     latence = 10;
     Vgrid = Ugrid = 64;
@@ -1930,11 +2103,6 @@ MathMod::MathMod(QWidget *parent, uint nbthreads,
     Xgrid = Ygrid = Zgrid = 64;
     CutX = CutY = CutZ = 0;
     LocalScene.VertxNumber = 0;
-    LabelInfos.setWindowFlags(Qt::WindowStaysOnTopHint| Qt::FramelessWindowHint);
-    LabelInfos.setAttribute(Qt::WA_TranslucentBackground);
-    LabelInfos.setAttribute(Qt::WA_NoSystemBackground);
-    LabelInfos.setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
-    LabelInfos.setWindowOpacity(0.8);
     FramesDir = "/home";
     hauteur_fenetre = 2*wh;
     timer = new QBasicTimer();
@@ -1944,66 +2112,12 @@ MathMod::MathMod(QWidget *parent, uint nbthreads,
         exit(0);
 }
 
-void MathMod::attachinfos()
-{
-    if(LocalScene.attachwininfos ==1)
-    {
-        QRect r = geometry();
-        LabelInfos.move(r.left(), r.top());
-        LabelInfos.setWindowFlags(Qt::WindowStaysOnTopHint| Qt::FramelessWindowHint);
-        LabelInfos.setAttribute(Qt::WA_TranslucentBackground);
-        LabelInfos.setAttribute(Qt::WA_NoSystemBackground);
-        if(LocalScene.infos == 1)
-            LabelInfos.show();
-    }
-    else
-    {
-        Qt::WindowFlags flags0 = LabelInfos.windowFlags();
-        flags0 &= ~Qt::FramelessWindowHint;
-        LabelInfos.setWindowFlags(flags0);
-        LabelInfos.setAttribute(Qt::WA_TranslucentBackground, false);
-        LabelInfos.setAttribute(Qt::WA_NoSystemBackground, false);
-        LabelInfos.setStyleSheet("QLabel { background-color : black; color : white; }");
-        LabelInfos.setAutoFillBackground(true);
-        if(LocalScene.infos == 1)
-            LabelInfos.show();
-    }
-}
-
-void MathMod::closeEvent(QCloseEvent *)
-{
-    LabelInfos.close();
-}
-
-void MathMod::moveEvent(QMoveEvent *)
-{
-    if(LocalScene.attachwininfos ==1)
-    {
-        QRect r = geometry();
-        LabelInfos.move(r.x(), r.y());
-    }
-}
-
 void MathMod::fill()
 {
     FillOk();
     update();
 }
 
-void MathMod::iso_infos()
-{
-    LocalScene.infos *= -1;
-    if(LocalScene.infos == 1)
-    {
-        QRect r = geometry();
-        LabelInfos.move(r.x(), r.y());
-        LabelInfos.show();
-    }
-    else
-        LabelInfos.hide();
-    update();
-}
-
 void MathMod::updateGL()
 {
     update();
