@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2021 by Abderrahman Taha                                *
+ *   Copyright (C) 2024 by Abderrahman Taha                                *
  *                                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -20,6 +20,8 @@
 
 #ifndef mathmod_H
 #define mathmod_H
+
+#include "comvar.h"
 #include "../pariso/isosurface/Iso3D.h"
 #include "../pariso/parametric/Model3D.h"
 #include <QFileDialog>
@@ -37,14 +39,13 @@
 #include <string>
 #include "../json_parser/parisodef.h"
 #include "../ui_modules/ParisoMathObject.h"
-#include <QMessageBox>
-#include <QOpenGLWidget>
 #include <QOpenGLFunctions>
 #include <QLabel>
 #include <QVector3D>
 #include <QQuaternion>
 #include <QMatrix4x4>
 #include <QPainter>
+#include <QGesture>
 
 class MathMod : public QOpenGLWidget, protected QOpenGLFunctions
 {
@@ -66,8 +67,6 @@ public:
     int xyzactivated, isomesh, uvactivated, uvactivated4D;
     ParisoMathObject RootObjet;
     jcollection collection;
-    QWidget *Parent;
-    QLabel LabelInfos;
     QString labelinfos;
     int FistTimecalibrate = -1;
     double hauteur_fenetre,difMaximum,decalage_xo,decalage_yo,decalage_zo;
@@ -215,8 +214,8 @@ public:
     qreal acc;
     QVector3D n;
 public:
-    MathMod(QWidget *, uint, uint initpargrid = 50, uint initisogrid = 40,
-            uint factx = 4, uint facty = 4, uint factz = 4);
+    MathMod(QWidget *, uint th  = Threads[0], uint initpargrid = InitParGrid, uint initisogrid = InitIsoGrid,
+            uint factx = CalculFactor[0], uint facty = CalculFactor[1], uint factz = CalculFactor[2]);
     ~MathMod();
     void ParametricSurfaceProcess(int type = 1);
     void ParisoObjectProcess();
@@ -224,8 +223,6 @@ public:
     void updateGL();
 public slots:
     void fill();
-    void iso_infos();
-    void attachinfos();
     void draw_norm_clicked();
     void linecolumn_valueChanged(int, ModelType type=PAR_TYPE);
     void line_valueChanged(int);
@@ -267,6 +264,8 @@ public slots:
     void mouseMoveEvent(QMouseEvent *)  override;
     void mouseReleaseEvent(QMouseEvent *)  override;
     void keyPressEvent(QKeyEvent *)  override;
+    bool event(QEvent *event) override;
+    void pinchTriggered(QPinchGesture*);
     virtual void run();
     void InitSpecularParameters();
     void Shininess(int);
@@ -277,8 +276,8 @@ public slots:
     void FramesShot();
     void FramesSave();
     QImage Copyscreenshot();
-    void moveEvent(QMoveEvent *) override;
-    void closeEvent(QCloseEvent *) override;
+    void grabGestures(const QList<Qt::GestureType> &gestures);
+    bool gestureEvent(QGestureEvent *event);
 public slots:
     void anim();
     void morph();
@@ -320,4 +319,5 @@ public slots:
     void LoadShadersFiles();
     void UpdateGL();
 };
+
 #endif
