@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2021 by Abderrahman Taha                                *
+ *   Copyright (C) 2024 by Abderrahman Taha                                *
  *                                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -22,7 +22,6 @@
 #define PARAMETERSOPTIONS_H
 
 #include "../json_parser/parisodef.h"
-#include "ui_parametersoptions.h"
 #include <QFileDialog>
 #include <QJsonObject>
 #include <QMainWindow>
@@ -36,22 +35,21 @@ struct ListeModelTexture
     QStringList listePigments;
 };
 
-class Parametersoptions : public QWidget
+class Parametersoptions
 {
-    Q_OBJECT
-
 public:
-    Parametersoptions(QWidget *parent = nullptr);
+    Parametersoptions();
     QString dotsymbol = ".";
     QString model = "CloseIso_2";
     QString filecollection = "mathmodcollection.js";
     QString fileconfig = "mathmodconfig.js";
-    QString fileconfig2 = "";
-    QString advancedmodels = "advancedmodels.js";
+    QString docpartialpath = "/documentation/index.html";
+    QString docabsolutepath = "";
+    QString version = "12.1";
     QString fullpath;
+    qreal scripteditorfontsize=14;
     QJsonObject JConfig, Collection, IsoParam;
     QPalette mypalette, mypalette2, darkpalette;
-    QApplication *MainApp;
     int ControlX = 20;
     int ControlY = 20;
     int GlwinX = 575;
@@ -65,37 +63,16 @@ public:
     int Diffuse[4]={80,80,80,100};
     int Shininess=110;
     bool glFrontFacingSupport=true;
-    int Threads[3]={8,1,64};
-    int CalculFactor[3]={4,4,4};
     int IsoMaxGrid = 305;
     int ParMaxGrid = 505;
-    int InitParGrid = 50;
-    int InitIsoGrid = 40;
 public slots:
-    void ReadConfigFile(QString, QJsonObject &);
+    //void ReadConfigFile(QString, QJsonObject &);
     void ReadJsonFile(QString, QJsonObject &);
-    void ReadCollectionFile(QString, QJsonObject &);
-    void SetStyleAndTheme(QApplication &, QString, QString);
-    void slot_about_clicked();
-    void GuiUpdate();
     void maxisogri_valueChanged(int);
     void maxpargri_valueChanged(int);
-    void on_loadconfig_clicked();
-    void SaveToFile_CurentMathModel(QJsonObject CurrentJsonObject);
-    void on_save_clicked();
-    void LoadConfig(QApplication &, int argc, char *argv[]);
+    void LoadConfig(int argc, char *argv[]);
     ListeModelTexture LoadCollectionModels(QJsonObject &, jcollection &, int);
     bool isFloat(std::string);
-    void on_comboBox_2_activated(const QString &);
-    void on_comboBox_3_activated(const QString &);
-    void on_comboBox_activated(const QString &);
-    void onred_2valueChanged(int);
-    void ongreen_2valueChanged(int);
-    void onblue_2valueChanged(int);
-    void on_TestConfig_clicked();
-
-public:
-    Ui::Parametersoptions ui;
 };
 
 #endif
