@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2021 by Abderrahman Taha                                *
+ *   Copyright (C) 2024 by Abderrahman Taha                                *
  *                                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -28,3 +28,9 @@ SlidersForm::SlidersForm(QWidget *parent) : QWidget(parent)
 }
 
 void SlidersForm::on_SaveButton_clicked() {}
+
+void SlidersForm::on_pushButton_clicked()
+{
+    this->close();
+}
+
